config = {
    'formatters': {
        'stdout': {
            'format': '%(message)s'
        },
        'short': {
            'datefmt': '%H:%M',
            'format': '%(asctime)s %(levelname)-7s %(message)s'
        },
        'full': {
            'datefmt': '%H:%M:%S',
            'format': '%(levelno)s %(asctime)s %(module)s.%(funcName)s:%(lineno)s %(message)s'
        },
    },
    'handlers': {
        'debug': {
            'class': 'logging.FileHandler',
            'filename': '/data/log/setux_debug.log',
            'formatter': 'full',
            'level': 'DEBUG',
            'mode': 'w'
        },
        'info': {
            'class': 'logging.FileHandler',
            'filename': '/data/log/setux_info.log',
            'formatter': 'short',
            'level': 'INFO',
            'mode': 'w'
        },
        'stdout': {
            'class': 'logging.StreamHandler',
            'formatter': 'stdout',
            'level': 'INFO'
        },
        'root': {
            'class': 'logging.FileHandler',
            'filename': '/data/log/setux_root.log',
            'formatter': 'short',
            'level': 'ERROR',
            'mode': 'w'
        },
    },
    'loggers': {
        'setux': {
            'handlers': ['debug', 'info', 'stdout'],
            'level': 'DEBUG',
            'propagate': False
        },
    },
    'root': {
        'handlers': ['root'], 'level': 'NOTSET'
    },
    'version': 1,
    'disable_existing_loggers': True,
 }



from logging import getLogger
from logging.config import dictConfig
from enum import Enum
from contextlib import contextmanager

from .config import config

dictConfig(config)

_logger_ = getLogger('setux')


class Verbosity(Enum):
    quiet = 0
    normal = 1
    verbose = 2


class Logger:
    def __init__(self, verbosity=None):
        self.verbosity = verbosity or Verbosity.normal

    @contextmanager
    def quiet(self):
        back = self.verbosity
        self.verbosity = Verbosity.quiet
        try:
            yield
        finally:
            self.verbosity = back

    def debug(self, *a):
        _logger_.debug(*a)

    def info(self, *a):
        if self.verbosity.value < Verbosity.normal.value:
            _logger_.debug(*a)
        else:
            _logger_.info(*a)

    def error(self, *a):
        _logger_.error(*a)

    def exception(self, *a):
        _logger_.exception(*a)


logger = Logger()

debug = logger.debug
info = logger.info
error = logger.error
exception = logger.exception

